jacinle.utils.argument
======================

.. automodule:: jacinle.utils.argument

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      UniqueValueGetter
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      asshape
      astuple
      canonicalize_args_list
      get_2dshape
      get_3dshape
      get_4dshape
      get_nd_shape
   
   

   
   
   








.. rubric:: Class UniqueValueGetter
.. autoclass:: UniqueValueGetter
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: asshape

.. autofunction:: astuple

.. autofunction:: canonicalize_args_list

.. autofunction:: get_2dshape

.. autofunction:: get_3dshape

.. autofunction:: get_4dshape

.. autofunction:: get_nd_shape


